@@ -7,7 +7,6 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Collection, Iterable, Iterator, MutableMapping, Optional, Union
 
 from .exceptions import AmbiguousParseTree
-from .nargs import nargs_min_and_max_sums
 from .utils import _parse_tree_target_repr
 
 if TYPE_CHECKING:
@@ -89,9 +88,6 @@ class PosNode(MutableMapping[Word, 'PosNode']):
             for node in self.values():
                 yield from node._link_params(_has_upper_bound(node))
 
-    def nargs_min_and_max(self) -> tuple[int, Union[int, float]]:
-        return nargs_min_and_max_sums(p.nargs for p in self.link_params(True))
-
     # region AnyWord Methods
 
     @property
